/*
  * Copyright 2013  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
/**
 * @file    context.cpp
 * @author  Leerang Song (leerang.song@samsung.com)
 */


#include "context.h"

#include <set>
#include <string>
#include <dpl/foreach.h>
#include <wrt-commons/security-origin-dao/security_origin_dao.h>

#include "util.h"

using namespace SecurityOriginDB;

namespace WebAppDetailSetting {
namespace {
// ETC
const char* const APP_SCHEME_ORIGIN = "local";
}
Context::Context()
{
}

Context::~Context()
{
}

void Context::setOriginData(void)
{
    // init old data
    originData.clear();

    // load origin data
    SecurityOriginDataList securityOriginDataList =
        dao->getSecurityOriginDataList();
    std::set<std::string> originSet;
    FOREACH(it, securityOriginDataList) {
        SecurityOriginDataPtr data = *it;
        Result result = dao->getResult(*data);
        if (result != RESULT_ALLOW_ALWAYS && result != RESULT_DENY_ALWAYS) {
            // skip case of temporary data
            continue;
        }

        std::string host = DPL::ToUTF8String(data->origin.host);
        if (host.empty()) {
            // in case of empty, host is packaged orgin
            // Before supported app scheme, origin set to "local"
            host = APP_SCHEME_ORIGIN;
        }
        originSet.insert(host);
    }

    // copy collected data
    FOREACH(it, originSet) {
        originData.push_back(*it);
    }
}

void Context::setPermissionData(void)
{
    // init old data
    permissionData.clear();

    // load origin data
    SecurityOriginDataList dataList =
        dao->getSecurityOriginDataList();

    FOREACH(it, dataList) {
        SecurityOriginDataPtr data = *it;

        // Skip allow once and deny once data
        Result result = dao->getResult(*data);
        if (result != RESULT_ALLOW_ALWAYS && result != RESULT_DENY_ALWAYS) {
            continue;
        }

        std::string host = DPL::ToUTF8String(data->origin.host);
        // In case of empty, host is packaged orgin
        // Before supported app scheme, origin set to "local"
        if (host.empty()) {
            host = APP_SCHEME_ORIGIN;
        }

        if (host == selectedOrigin) {
            permissionData.push_back(data);
        }
    }
}

void Context::setSelectedOrigin(unsigned int index)
{
    selectedOrigin = originData[index];
}

void Context::removePermissionData(unsigned int index)
{
    SecurityOriginDataPtr originData = permissionData[index];
    dao->removeSecurityOriginData(*originData);
}

void Context::removeAllPermissionData(void)
{
    FOREACH(it, permissionData) {
        dao->removeSecurityOriginData(*(*it));
    }
    permissionData.clear();
}

bool Context::getPermissionResult(unsigned int index)
{
    _D("called");
    SecurityOriginDataPtr originData = permissionData[index];
    Result result = dao->getResult(*originData);

    bool ret = false;
    if (result == RESULT_ALLOW_ALWAYS) {
        ret = true;
    } else if (result == RESULT_DENY_ALWAYS) {
        ret = false;
    } else {
        _W("Uknown result : %d", result);
        ret = false;
    }
    return ret;
}

} // namespace WebAppDetailSetting

