/*
  * Copyright 2012  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */

#ifndef WEB_SRC_SETTING_WEBAPP_DETAIL_EXCEPTIONSVIEW_H_
#define WEB_SRC_SETTING_WEBAPP_DETAIL_EXCEPTIONSVIEW_H_

#include <Evas.h>

#undef None
#include <memory>
#include <wrt-commons/security-origin-dao/security_origin_dao.h>
#include <wrt-commons/security-origin-dao/security_origin_dao_types.h>

namespace SecurityOriginDB {
class SecurityOriginDAO;
struct SecurityOriginData;
}

namespace WebAppDetailSetting {

class ExceptionsView
{
  public:
    ExceptionsView(Evas_Object *naviframe, const std::string& pkgId);
    ~ExceptionsView(void);

    bool loadView(void);
    void loadEmptyView(Evas_Object* genlist);
    void loadExceptionsSettingsView(
        Evas_Object* genlist,
        SecurityOriginDB::SecurityOriginDataList securityOriginDataList);

  private:
    Evas_Object *m_naviframe;
    DPL::String m_pkgId;
    SecurityOriginDB::SecurityOriginDAOPtr m_securityOriginDao;

    //Genlist
    static char* getEmptyTextCallback(
        void* data,
        Evas_Object* obj,
        const char* part);
    static char* getTextCallback(
        void* data,
        Evas_Object* obj,
        const char* part);
    static void delCallback(
        void* data,
        Evas_Object* obj);
    static void selectedCallback(
        void* data,
        Evas_Object* obj,
        void* eventInfo);

    //Popup
    static void removeItemCallback(
        void* data,
        Evas_Object* obj,
        void* eventInfo);
    static void closePopupCallback(
        void* data,
        Evas_Object* obj,
        void* eventInfo);
};

class ExceptionsSettingsData
{
  public:
    SecurityOriginDB::SecurityOriginDAO* m_originDao;
    SecurityOriginDB::SecurityOriginData m_originData;

    ExceptionsSettingsData(
        SecurityOriginDB::SecurityOriginDAO* dao,
        SecurityOriginDB::SecurityOriginData data) :
            m_originDao(dao),
            m_originData(data)
    {
    };
};

} /* WebAppDetailSetting */

#endif /* WEB_SRC_SETTING_WEBAPP_DETAIL_EXCEPTIONSVIEW_H_ */
