/*
  * Copyright 2012  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */

#include <Elementary.h>
#include <efl_assist.h>
#include <ui-gadget-module.h>

#include <dpl/assert.h>

#include "util.h"
#include "main_view.h"
#include "origin_view.h"
#include "exceptionsview.h"

namespace WebAppDetailSetting {
namespace {
} // anonymous namspace

MainView::MainView(ui_gadget_h ug) :
    m_ug(ug),
    m_layout(NULL),
    m_bg(NULL)
{
    m_originView.reset();
}

MainView::~MainView(void)
{
    m_originView.reset();
}

void MainView::init(const std::string& pkgId)
{
    Assert(m_ug);
    Evas_Object* parent =
        static_cast<Evas_Object*>(ug_get_parent_layout(m_ug));

    // create base layout
    m_layout = createLayout(parent);
    m_bg = createBg(m_layout);
    Evas_Object* naviframe = createNaviframe(m_layout);

    // create main "WebSetting Menu"
    m_originView.reset(new OriginView(naviframe, pkgId));
    m_originView->init();
}

Evas_Object* MainView::getLayout(void) const
{
    return m_layout;
}

Evas_Object* MainView::createLayout(Evas_Object* parent)
{
    Assert(parent);
    Evas_Object* layout = elm_layout_add(parent);
    elm_layout_theme_set(layout, "layout", "application", "default");
    return layout;
}

Evas_Object* MainView::createBg(Evas_Object* parent)
{
    Assert(parent);
    Evas_Object* bg = elm_bg_add(parent);
    elm_object_part_content_set(parent, "elm.swallow.bg", bg);
    return bg;
}

Evas_Object* MainView::createNaviframe(Evas_Object* parent)
{
    Assert(parent);
    Evas_Object* naviframe = elm_naviframe_add(parent);
    ea_object_event_callback_add(naviframe,
                                 EA_CALLBACK_BACK,
                                 backCallback,
                                 this);
    elm_object_part_content_set(parent, "elm.swallow.content", naviframe);
    return naviframe;
}

void MainView::backCallback(void* data, Evas_Object* obj, void* eventInfo)
{
    UNUSED_PARAM(eventInfo);

    Assert(obj);
    if (elm_naviframe_bottom_item_get(obj) == elm_naviframe_top_item_get(obj))
    {
        Assert(data);
        MainView* This = static_cast<MainView*>(data);
        ug_destroy_me(This->m_ug);
    } else {
        elm_naviframe_item_pop(obj);
    }
}

} /* WebAppDetailSetting */
