/*
  * Copyright 2013  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
/**
 * @file    permission_view.h
 * @author  Leerang Song (leerang.song@samsung.com)
 */


#ifndef WEBAPP_DETAIL_PERMISSION_VIEW_H_
#define WEBAPP_DETAIL_PERMISSION_VIEW_H_

#include <memory>
#include <string>
#include <vector>
#include <Elementary.h>
#include <dpl/fast_delegate.h>

#undef None // conflict with ui-gadget-module.h
#include <wrt-commons/security-origin-dao/security_origin_dao.h>

namespace WebAppDetailSetting {
// Forward declare
class Context;
class PermissionDeleteView;
class CtxpopupView;
class PermissionView
{
  public:
    PermissionView(Context& context);
    virtual ~PermissionView(void);

    void init(void);

  private:
    void loadView(void);
    void loadEmptyView(void);

    // callback
    static Eina_Bool naviframeItemPopCallback(void* data,
                                              Elm_Object_Item* it);
    static char* getEmptyTextCallback(void* data,
                                      Evas_Object* obj,
                                      const char* part);
    static char* getTextCallback(void* data,
                                 Evas_Object* obj,
                                 const char* part);
    static Evas_Object* getContentCallback(void* data,
                                           Evas_Object* obj,
                                           const char* part);
    static void delCallback(void* data, Evas_Object* obj);
    static void selectedMoreCallback(void* data, Evas_Object* obj, void* eventInfo);

    // ctxpopup callback
    void ctxpopupDelete(void);
    void ctxpopupReset(void);

    // PermissionDeleteView update callback
    void updateCallback(void);

    Context& m_context;
    Evas_Object* m_genlist;

    std::unique_ptr<CtxpopupView> m_ctxpopupView;
    std::unique_ptr<PermissionDeleteView> m_permissionDeleteView;
};
} // namespace WebAppDetailSetting

#endif // WEBAPP_DETAIL_PERMISSION_VIEW_H_
